@@ -305,6 +305,11 @@ class Recipe:
             zeo_address = options.get('zeo-address', '8100')
 
             zodb_cache_size = options.get('zodb-cache-size', '5000')
+            zodb_cache_size_bytes = options.get('zodb-cache-size-bytes', None)
+            if zodb_cache_size_bytes:
+                zodb_cache_size_bytes = "cache-size-bytes %s" % zodb_cache_size_bytes
+            else:
+                zodb_cache_size_bytes = ""
             zeo_client_cache_size = options.get('zeo-client-cache-size', '30MB')
             zeo_storage = options.get('zeo-storage', '1')
 
@@ -313,11 +318,17 @@ class Recipe:
                 zeo_var_dir = options.get('zeo-var',
                                           os.path.join(instance_home, 'var'))
                 zeo_client_client = options.get('zeo-client-client', '')
+                zeo_client_min_disconnect_poll = options.get('min-disconnect-poll', "")
+                zeo_client_max_disconnect_poll = options.get('max-disconnect-poll', "")
                 shared_blob_dir = options.get('shared-blob', 'no')
                 if zeo_client_name:
                     zeo_client_name = 'zeo-client-name %s' % zeo_client_name
                 if zeo_client_client:
                     zeo_client_client = 'client %s' % zeo_client_client
+                if zeo_client_min_disconnect_poll:
+                    zeo_client_min_disconnect_poll = "min-disconnect-poll %s" % zeo_client_min_disconnect_poll
+                if zeo_client_max_disconnect_poll:
+                    zeo_client_max_disconnect_poll = "max-disconnect-poll %s" % zeo_client_max_disconnect_poll
                 if options.get('zeo-username', ''):
                     if not options.get('zeo-password', ''):
                         raise zc.buildout.UserError('No ZEO password specified')
@@ -343,6 +354,8 @@ class Recipe:
                     zeo_client_client = zeo_client_client,
                     zeo_storage = zeo_storage,
                     zeo_var_dir=zeo_var_dir,
+                    zeo_client_min_disconnect_poll=zeo_client_min_disconnect_poll,
+                    zeo_client_max_disconnect_poll=zeo_client_max_disconnect_poll,
                     )
             else:
                 # no zeo-client
@@ -390,6 +403,7 @@ class Recipe:
                                         webdav_address = webdav_address,
                                         zserver_threads = zserver_threads,
                                         zodb_cache_size = zodb_cache_size,
+                                        zodb_cache_size_bytes = zodb_cache_size_bytes,
                                         zeo_client_name = zeo_client_name,
                                         zodb_tmp_storage = zodb_tmp_storage,
                                         pid_file = pid_file,
@@ -636,6 +650,8 @@ zeo_storage_template="""
       cache-size %(zeo_client_cache_size)s
       %(zeo_authentication)s
       %(zeo_client_client)s
+      %(zeo_client_min_disconnect_poll)s
+      %(zeo_client_max_disconnect_poll)s
     </zeoclient>
 """.strip()
 
@@ -651,6 +667,8 @@ zeo_blob_storage_template="""
       cache-size %(zeo_client_cache_size)s
       %(zeo_authentication)s
       %(zeo_client_client)s
+      %(zeo_client_min_disconnect_poll)s
+      %(zeo_client_max_disconnect_poll)s
     </zeoclient>
 """.strip()
 
@@ -751,6 +769,7 @@ verbose-security %(verbose_security)s
 <zodb_db main>
     # Main database
     cache-size %(zodb_cache_size)s
+    %(zodb_cache_size_bytes)s
 %(storage_snippet)s
     mount-point /
 </zodb_db>
